This directory contains patches that we use to create the Year in Music reviews at the end of the year.
Given the limited use, they've been moved away from the other patches in order to not confuse the normal
flow of the other patches
